summaryrefslogtreecommitdiff
path: root/genpacksizetables.pl
diff options
context:
space:
mode:
authorNicholas Clark <nick@ccl4.org>2005-01-27 19:26:21 +0000
committerNicholas Clark <nick@ccl4.org>2005-01-27 19:26:21 +0000
commita72c271bac70ecc52cda8ed4ba689c8816509735 (patch)
tree759a16bf46116730f4a86af465376a76951480a7 /genpacksizetables.pl
parent19e169bfb15baa663525996999bfeb9bd76bdc62 (diff)
downloadperl-a72c271bac70ecc52cda8ed4ba689c8816509735.tar.gz
Retrieve the flag bit that only 'p' uses, so that it is spare for
future use. p4raw-id: //depot/perl@23892
Diffstat (limited to 'genpacksizetables.pl')
-rwxr-xr-xgenpacksizetables.pl12
1 files changed, 6 insertions, 6 deletions
diff --git a/genpacksizetables.pl b/genpacksizetables.pl
index b3e3a8c39c..2987499b95 100755
--- a/genpacksizetables.pl
+++ b/genpacksizetables.pl
@@ -7,10 +7,10 @@ use Encode;
my @lines = grep {!/^#/} <DATA>;
sub addline {
- my ($arrays, $chrmap, $letter, $arrayname, $noone, $nocsum, $size,
+ my ($arrays, $chrmap, $letter, $arrayname, $spare, $nocsum, $size,
$condition) = @_;
my $line = "/* $letter */ $size";
- $line .= " | PACK_SIZE_CANNOT_ONLY_ONE" if $noone;
+ $line .= " | PACK_SIZE_SPARE" if $spare;
$line .= " | PACK_SIZE_CANNOT_CSUM" if $nocsum;
$line .= ",";
# And then the hack
@@ -24,7 +24,7 @@ sub output_tables {
my $chrmap = shift;
foreach (@_) {
- my ($letter, $shriek, $noone, $nocsum, $size, $condition)
+ my ($letter, $shriek, $spare, $nocsum, $size, $condition)
= /^([A-Za-z])(!?)\t(\S*)\t(\S*)\t([^\t\n]+)(?:\t+(.*))?$/;
die "Can't parse '$_'" unless $size;
@@ -36,7 +36,7 @@ sub output_tables {
}
addline (\%arrays, $chrmap, $letter, $shriek ? 'shrieking' : 'normal',
- $noone, $nocsum, $size, $condition);
+ $spare, $nocsum, $size, $condition);
}
my %earliest;
@@ -100,7 +100,7 @@ output_tables (\%ebcdicmap, @lines);
print "#endif\n";
__DATA__
#Symbol nooone nocsum size
c char
C unsigned char
U char
@@ -126,7 +126,7 @@ N =SIZE32
V! =SIZE32 PERL_PACK_CAN_SHRIEKSIGN
N! =SIZE32 PERL_PACK_CAN_SHRIEKSIGN
L =SIZE32
-p * * char *
+p * char *
w * char
q Quad_t HAS_QUAD
Q Uquad_t HAS_QUAD
@@ -100,7 +100,7 @@ output_tables (\%ebcdicmap, @lines);
print "#endif\n";
__DATA__
-#Symbol nooone nocsum size
+#Symbol spare nocsum size
c char
C unsigned char